Identity Methods — Rucio 1.12.2 documentation

# Identity Methods

Interface for identity abstraction layer

`rucio.api.identity.` `add_account_identity`(identity_key, id_type, account, email, issuer, default=False)

  Adds a membership association between identity and account.

  Parameters: | identity_key – The identity key name. For example x509 DN, or a username. id_type – The type of the authentication (x509, gss, userpass). account – The account name. email – The Email address associated with the identity. issuer – The issuer account. default – If True, the account should be used by default with the provided identity.

`rucio.api.identity.` `add_identity`(identity_key, id_type, email, password=None)

  Creates a user identity.

  Parameters: | identity_key – The identity key name. For example x509 DN, or a username. id_type – The type of the authentication (x509, gss, userpass) email – The Email address associated with the identity. password – If type==userpass, this sets the password.

`rucio.api.identity.` `del_account_identity`(identity_key, id_type, account)

  Removes a membership association between identity and account.

  Parameters: | identity_key – The identity key name. For example x509 DN, or a username. id_type – The type of the authentication (x509, gss, userpass). account – The account name.

`rucio.api.identity.` `del_identity`(identity_key, id_type)

  Deletes a user identity.

  Parameters: | identity_key – The identity key name. For example x509 DN, or a username. id_type – The type of the authentication (x509, gss, userpass).

`rucio.api.identity.` `get_default_account`(identity_key, id_type)

  Returns the default account for this identity.

  Parameters: | identity_key – The identity key name. For example x509 DN, or a username. id_type – The type of the authentication (x509, gss, userpass).

`rucio.api.identity.` `list_accounts_for_identity`(identity_key, id_type)

  Returns a list of all accounts for an identity.

  Parameters: | identity – The identity key name. For example x509 DN, or a username. id_type – The type of the authentication (x509, gss, userpass).

  returns: A list of all accounts for the identity.

`rucio.api.identity.` `list_identities`(**kwargs)

  Returns a list of all enabled identities.

  returns: A list of all enabled identities.